@@ -1,7 +1,7 @@
-from sqlobject import *
-from sqlobject.tests.dbtest import *
-from sqlobject.views import *
-from sqlobject.sqlbuilder import ImportProxy, Alias
+from sqlobject import SQLObject, StringCol
+from sqlobject.sqlbuilder import Alias, ImportProxy, tablesUsedSet
+from sqlobject.views import ViewSQLObject
+
 
 def testSimple():
     nyi = ImportProxy('NotYetImported')
@@ -15,14 +15,17 @@ def testSimple():
     assert str(x) == 'not_yet_imported.a_name'
     assert str(y) == 'not_yet_imported.a_name'
 
+
 def testAddition():
     nyi = ImportProxy('NotYetImported2')
-    x = nyi.q.name+nyi.q.name
+    x = nyi.q.name + nyi.q.name
 
     class NotYetImported2(SQLObject):
         name = StringCol(dbName='a_name')
 
-    assert str(x) == '((not_yet_imported2.a_name) + (not_yet_imported2.a_name))'
+    assert str(x) == \
+        '((not_yet_imported2.a_name) + (not_yet_imported2.a_name))'
+
 
 def testOnView():
     nyi = ImportProxy('NotYetImportedV')
@@ -38,6 +41,7 @@ def testOnView():
 
     assert str(x) == 'not_yet_imported_v.name'
 
+
 def testAlias():
     nyi = ImportProxy('NotYetImported4')
     y = Alias(nyi, 'y')
